<?
// Version 2015062301, (c) 2010, 2015 by W.R.Schulz, Kngen
require_once '_FormBean.php';
require_once '../_terminVO.php';

class teditBean
extends FormBean
{
  const MIN_TSOFFS  = 1;
  const MAX_TSOFFS  = 120;
  const DEF_TSOFFS  = 7;
  const MAX_LEN_MSG = 200;

  public $m_ID;
  public $m_Type;
  public $m_T1Date;
  public $m_TYDate;
  public $m_TMoOffs;
  public $m_TSOffs;
  public $m_TSDate;
  public $m_Msg;

  protected function loadTermin()
  {
    global $db_host, $db_user, $db_pass, $db_catalog, $db_table;

    $db = mysqli_connect( $db_host, $db_user, $db_pass, $db_catalog );

    $t        = new terminVO();
    $t->m_ID  = $this->m_ID;

    if ( !$t->load( $db, $db_table ) )
    {
      $this->m_Errors['type'] = 'Der Datensatz konnte nicht aus der Datenbank gelesen werden.';
    }
    else
    {
      $this->m_ID   = $t->m_ID;
      $this->m_Type = $t->m_Type;
      $this->m_Msg  = $t->m_Msg;

      switch ( $this->m_Type )
      {
        case '1':
          $this->m_T1Date = date( "Y-m-d", $t->m_Time );
          break;
        case 'y':
          $this->m_TYDate = date( "m-d", $t->m_Time );
          break;
        case 'mo':
          $this->m_TMoOffs = $t->m_Inc;
          break;
        case 's':
          $this->m_TSOffs = $t->m_Inc;
          $this->m_TSDate = date( "Y-m-d", $t->m_Time );
          break;
        default:
          // NOP
      }
    }

    mysqli_close( $db );
  }

  protected function evalRequest( $request )
  {
    parent::evalRequest( $request );

    if ( isset( $request['id'] ) )      $this->m_ID       = $request['id'];
    if ( isset( $request['type'] ) )    $this->m_Type     = trim( $request['type'] );
    if ( isset( $request['t1date'] ) )  $this->m_T1Date   = trim( $request['t1date'] );
    if ( isset( $request['tydate'] ) )  $this->m_TYDate   = trim( $request['tydate'] );
    if ( isset( $request['tmooffs'] ) ) $this->m_TMoOffs  = $request['tmooffs'];
    if ( isset( $request['tsoffs'] ) )  $this->m_TSOffs   = $request['tsoffs'];
    if ( isset( $request['tsdate'] ) )  $this->m_TSDate   = trim( $request['tsdate'] );
    if ( isset( $request['msg'] ) )     $this->m_Msg      = htmlentities( $request['msg'], ENT_QUOTES );

    if ( $this->m_ID > 0  &&  !$this->isSave() )
    {
      $this->loadTermin();
    }
  }

  protected function chkDate( $dateStr )
  {
    $rVal = false;

    // Aufbau des Datum-Strings: "yyyy-mm-dd"
    if ( strlen( $dateStr ) == 10 )
    {
      $y = substr( $dateStr, 0, 4 );
      $m = substr( $dateStr, 5, 2 );
      $d = substr( $dateStr, 8, 2 );

      $rVal = checkdate( $m, $d, $y );
    }

    return $rVal;
  }

  protected function verifyT1()
  {
    if ( empty( $this->m_T1Date ) )
    {
      $this->m_Errors['t1date'] = 'Es muss ein Datum angegeben werden.';
    }
    else
    {
      if ( !$this->chkdate( $this->m_T1Date ) )
      {
        $this->m_Errors['t1date'] = 'Das Datum ist ungltig.';
      }
      else
      {
        if ( strcmp( $this->m_T1Date, date( 'Y-m-d' ) ) < 0 )
        {
          $this->m_Errors['t1date'] = 'Das Datum liegt in der Vergangenheit.';
        }
      }
    }
  }

  protected function verifyTY()
  {
    if ( empty( $this->m_TYDate ) )
    {
      $this->m_Errors['tydate'] = 'Es m&uuml;ssen Monat und Tag angegeben werden.';
    }
    else
    {
      if ( !$this->chkdate( date( 'Y' ).'-'.$this->m_TYDate ) )
      {
        $this->m_Errors['tydate'] = 'Das Monat und/oder Tag ist ungltig.';
      }
      else
      {
        if (    strcmp( substr( $this->m_TYDate, 0, 2 ), '02' ) == 0
             && strcmp( substr( $this->m_TYDate, 3, 2 ), '29' ) == 0
           )
        {
          $this->m_Errors['tydate'] = 'Der 29. Februar wird an dieser Stelle derzeit nicht unterst&uuml;tzt..';
        }
      }
    }
  }

  protected function verifyTMo()
  {
    if ( $this->m_TMoOffs < 0  ||  $this->m_TMoOffs > 27 )
    {
      $this->m_Errors['tmooffs'] = 'Es wurde kein g&uuml;tiger Tag ausgew&auml;hlt.';
    }
  }

  protected function verifyTS()
  {
    if ( $this->m_TSOffs < self::MIN_TSOFFS  ||  $this->m_TSOffs > self::MAX_TSOFFS )
    {
      $this->m_Errors['tsoffs'] = sprintf( 'Wert muss zwischen %d und %d liegen.', self::MIN_TSOFFS, self::MAX_TSOFFS );
    }

    if ( empty( $this->m_TSDate ) )
    {
      $this->m_Errors['tsdate'] = 'Es muss ein Startdatum angegeben werden.';
    }
    else
    {
      if ( !$this->chkdate( $this->m_TSDate ) )
      {
        $this->m_Errors['tsdate'] = 'Das Datum ist ungltig.';
      }
    }
  }

  protected function verify()
  {
    parent::verify();

    switch ( $this->m_Type )
    {
      case '1':
        $this->verifyT1();
        break;
      case 'y':
        $this->verifyTY();
        break;
      case 'mo':
        $this->verifyTMo();
        break;
      case 's':
        $this->verifyTS();
        break;
      default:
        $this->m_Errors['type'] = 'Es wurde kein g&uuml;ltiger Termin-Typ ausgew&auml;hlt.';
    }

    if ( empty( $this->m_Msg ) )
    {
      $this->m_Errors['msg'] = 'Es muss eine Beschreibung angegeben werden.';
    }
    else
    {
      if ( strlen( $this->m_Msg ) > self::MAX_LEN_MSG )
      {
        $this->m_Errors['msg'] = sprintf( 'Die Beschreibung darf max. %d Zeichen umfassen', self::MAX_LEN_MSG );
      }
    }
  }

  protected function createTime()
  {
    $rVal = 0;
    $tmp  = null;

    switch ( $this->m_Type )
    {
      case '1':
        $tmp = $this->m_T1Date;
        break;
      case 'y':
        $tmp = date( 'Y' ).'-'.$this->m_TYDate;
        break;
      case 'mo':
        // NOP
        break;
      case 's':
        $tmp = $this->m_TSDate;
        break;
      default:
        // NOP;
    }

    if ( !empty( $tmp ) )
    {
      // Aufbau: "yyyy-mm-dd"
      $rVal = mktime( 0, 0, 0, substr( $tmp, 5, 2 ), substr( $tmp, 8, 2 ), substr( $tmp, 0, 4 ) );
    }

    return $rVal;
  }

  protected function createInc()
  {
    $rVal = '0';

    switch ( $this->m_Type )
    {
      case 'mo':
        $rVal = $this->m_TMoOffs;
        break;
      case 's':
        $rVal = $this->m_TSOffs;
        break;
      default:
        // NOP;
    }

    return $rVal;
  }

  protected function init()
  {
    $this->m_ID      = 0;
    $this->m_Type    = null;
    $this->m_T1Date  = null;
    $this->m_TYDate  = null;
    $this->m_TMoOffs = -1;
    $this->m_TSOffs  = self::DEF_TSOFFS;
    $this->m_TSDate  = null;
    $this->m_Msg     = null;
  }

  public function __construct( $request )
  {
    $this->init();

    parent::__construct( $request );
  }

  public function clear()
  {
    $this->init();
  }

  public function writeChanges()
  {
    global $db_host, $db_user, $db_pass, $db_catalog, $db_table;

    $rVal = false;

    if ( $db = mysqli_connect( $db_host, $db_user, $db_pass, $db_catalog ) )
    {
      $t = new terminVO();

      $t->m_ID    = $this->m_ID;
      $t->m_Time  = $this->createTime();
      $t->m_Type  = $this->m_Type;
      $t->m_Inc   = $this->createInc();
      $t->m_Msg   = $this->m_Msg;

      $rVal = $t->save( $db, $db_table );

      mysqli_close( $db );
    }

    return $rVal;
  }
}
?>
